This folder is where LIPIDMAPS, HMDB, MoNA will be automatically downloaded. These are the defaults for the various annotation procedures in the pipeline. 

These sources can be downloaded using the `download extras` command. By doing this, you agree to the terms of service for those sources. Notably, they are not for commercial use. 